@@ -1,25 +1,34 @@
+import time
 from unittest import TestCase
 
 from nose import SkipTest
-import pyes
+import pyelasticsearch
 
 from elasticutils import get_es, S
 
 
-class ElasticTestCase(TestCase):
-    """Superclass for ElasticSearch-using test cases.
+class ESTestCase(TestCase):
+    """Superclass for Elasticsearch-using test cases.
 
-    :cvar index_name: string; name of the index to use
-    :cvar skip_tests: bool; if ElasticSearch isn't available, then
-        this is True and therefore tests should be skipped for this
-        class
+    :property index_name: name of the index to use
+    :property mapping_type_name: the mapping type name
+    :property es_settings: settings to use to build a pyelasticsearch 
+        ElasticSearch object.
+    :property mapping: the mapping to use when creating an index
+    :property data: any data to add to the index in setup_class
+    :property skip_tests: if Elasticsearch isn't available, then this
+        is True and therefore tests should be skipped for this class
 
     For examples of usage, see the other ``test_*.py`` files.
 
     """
     index_name = 'elasticutilstest'
     mapping_type_name = 'elasticutilsmappingtype'
-
+    es_settings = {
+        'urls': ['http://localhost:9200']
+        }
+    mapping = {}
+    data = []
     skip_tests = False
 
     @classmethod
@@ -31,9 +40,15 @@ class ElasticTestCase(TestCase):
         """
         # Note: TestCase has no setup_class
         try:
-            get_es().collect_info()
-        except pyes.urllib3.MaxRetryError:
+            get_es().health()
+        except pyelasticsearch.exceptions.ConnectionError:
             cls.skip_tests = True
+            return
+
+        if cls.data:
+            cls.create_index(settings={'mappings': cls.mapping})
+            cls.index_data(cls.data)
+            cls.refresh()
 
     @classmethod
     def teardown_class(cls):
@@ -51,12 +66,11 @@ class ElasticTestCase(TestCase):
         """
         if self.skip_tests:
             raise SkipTest
-
-        super(ElasticTestCase, self).setUp()
+        super(ESTestCase, self).setUp()
 
     @classmethod
     def get_es(cls):
-        return get_es(default_indexes=[cls.index_name])
+        return get_es(**cls.es_settings)
 
     @classmethod
     def get_s(cls, mapping_type=None):
@@ -64,39 +78,43 @@ class ElasticTestCase(TestCase):
             s = S(mapping_type)
         else:
             s = S()
-        return s.indexes(cls.index_name).doctypes(cls.mapping_type_name)
+        return (s.es(**cls.es_settings)
+                 .indexes(cls.index_name)
+                 .doctypes(cls.mapping_type_name))
 
     @classmethod
-    def create_index(cls):
+    def create_index(cls, settings=None):
         es = cls.get_es()
         try:
-            es.delete_index_if_exists(cls.index_name)
-        except pyes.exceptions.IndexMissingException:
-            # pyes 0.15 throws an IndexMissingException despite the
-            # fact that the method should allow for that.
+            es.delete_index(cls.index_name)
+        except pyelasticsearch.exceptions.ElasticHttpNotFoundError:
             pass
-        es.create_index(cls.index_name)
+        if settings:
+            settings = {'settings': settings}
+        else:
+            settings = {}
+        es.create_index(cls.index_name, **settings)
 
     @classmethod
-    def index_data(cls, data, index=None, doctype=None, create_index=False):
+    def index_data(cls, data, index=None, doctype=None):
         index = index or cls.index_name
         doctype = doctype or cls.mapping_type_name
 
         es = cls.get_es()
 
-        if create_index:
-            cls.create_index()
-
+        # TODO: change this to a bulk index
         for item in data:
-            es.index(item, index, doctype, bulk=True, id=item['id'])
+            es.index(index, doctype, item, id=item['id'])
 
-        es.flush_bulk(forced=True)
         cls.refresh()
 
     @classmethod
     def cleanup_index(cls):
         es = cls.get_es()
-        es.delete_index_if_exists(cls.index_name)
+        try:
+            es.delete_index(cls.index_name)
+        except pyelasticsearch.exceptions.ElasticHttpNotFoundError:
+            pass
 
     @classmethod
     def refresh(cls, timesleep=0):
@@ -105,10 +123,12 @@ class ElasticTestCase(TestCase):
         This refreshes the index specified by `self.index_name`.
 
         :arg timesleep: int; number of seconds to sleep after telling
-            ES to refresh
+            Elasticsearch to refresh
 
         """
-        cls.get_es().refresh(cls.index_name, timesleep=timesleep)
+        cls.get_es().refresh(cls.index_name)
+        if timesleep:
+            time.sleep(timesleep)
 
 
 def facet_counts_dict(qs, field):
